summaryrefslogtreecommitdiff
path: root/cui/source/tabpages/tabarea.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'cui/source/tabpages/tabarea.cxx')
-rw-r--r--cui/source/tabpages/tabarea.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/cui/source/tabpages/tabarea.cxx b/cui/source/tabpages/tabarea.cxx
index 115164bba772..4e873f4cb021 100644
--- a/cui/source/tabpages/tabarea.cxx
+++ b/cui/source/tabpages/tabarea.cxx
@@ -90,7 +90,7 @@ SvxAreaTabDialog::SvxAreaTabDialog
mnDlgType( 0 ),
mnPos( 0 ),
mbAreaTP( sal_False ),
- mbDeleteColorTable( TRUE )
+ mbDeleteColorTable( sal_True )
{
FreeResource();
@@ -253,7 +253,7 @@ short SvxAreaTabDialog::Ok()
SavePalettes();
// Es wird RET_OK zurueckgeliefert, wenn wenigstens eine
// TabPage in FillItemSet() TRUE zurueckliefert. Dieses
// geschieht z.Z. standardmaessig.
return( SfxTabDialog::Ok() );
}
@@ -271,7 +271,7 @@ IMPL_LINK_INLINE_END( SvxAreaTabDialog, CancelHdlImpl, void *, p )
// -----------------------------------------------------------------------
-void SvxAreaTabDialog::PageCreated( USHORT nId, SfxTabPage &rPage )
+void SvxAreaTabDialog::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
{
switch( nId )
{
@@ -253,7 +253,7 @@ short SvxAreaTabDialog::Ok()
SavePalettes();
// Es wird RET_OK zurueckgeliefert, wenn wenigstens eine
- // TabPage in FillItemSet() TRUE zurueckliefert. Dieses
+ // TabPage in FillItemSet() sal_True zurueckliefert. Dieses
// geschieht z.Z. standardmaessig.
return( SfxTabDialog::Ok() );